# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ApiUsageRow(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ApiUsageRow - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'client_id': 'str',
            'client_name': 'str',
            'organization_id': 'str',
            'user_id': 'str',
            'template_uri': 'str',
            'http_method': 'str',
            'status200': 'int',
            'status300': 'int',
            'status400': 'int',
            'status500': 'int',
            'status429': 'int',
            'requests': 'int',
            'date': 'datetime'
        }

        self.attribute_map = {
            'client_id': 'clientId',
            'client_name': 'clientName',
            'organization_id': 'organizationId',
            'user_id': 'userId',
            'template_uri': 'templateUri',
            'http_method': 'httpMethod',
            'status200': 'status200',
            'status300': 'status300',
            'status400': 'status400',
            'status500': 'status500',
            'status429': 'status429',
            'requests': 'requests',
            'date': 'date'
        }

        self._client_id = None
        self._client_name = None
        self._organization_id = None
        self._user_id = None
        self._template_uri = None
        self._http_method = None
        self._status200 = None
        self._status300 = None
        self._status400 = None
        self._status500 = None
        self._status429 = None
        self._requests = None
        self._date = None

    @property
    def client_id(self):
        """
        Gets the client_id of this ApiUsageRow.
        Client Id associated with this query result

        :return: The client_id of this ApiUsageRow.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this ApiUsageRow.
        Client Id associated with this query result

        :param client_id: The client_id of this ApiUsageRow.
        :type: str
        """
        
        self._client_id = client_id

    @property
    def client_name(self):
        """
        Gets the client_name of this ApiUsageRow.
        Client Name associated with this query result

        :return: The client_name of this ApiUsageRow.
        :rtype: str
        """
        return self._client_name

    @client_name.setter
    def client_name(self, client_name):
        """
        Sets the client_name of this ApiUsageRow.
        Client Name associated with this query result

        :param client_name: The client_name of this ApiUsageRow.
        :type: str
        """
        
        self._client_name = client_name

    @property
    def organization_id(self):
        """
        Gets the organization_id of this ApiUsageRow.
        Organization Id associated with this query result

        :return: The organization_id of this ApiUsageRow.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """
        Sets the organization_id of this ApiUsageRow.
        Organization Id associated with this query result

        :param organization_id: The organization_id of this ApiUsageRow.
        :type: str
        """
        
        self._organization_id = organization_id

    @property
    def user_id(self):
        """
        Gets the user_id of this ApiUsageRow.
        User Id associated with this query result

        :return: The user_id of this ApiUsageRow.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this ApiUsageRow.
        User Id associated with this query result

        :param user_id: The user_id of this ApiUsageRow.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def template_uri(self):
        """
        Gets the template_uri of this ApiUsageRow.
        Template Uri associated with this query result

        :return: The template_uri of this ApiUsageRow.
        :rtype: str
        """
        return self._template_uri

    @template_uri.setter
    def template_uri(self, template_uri):
        """
        Sets the template_uri of this ApiUsageRow.
        Template Uri associated with this query result

        :param template_uri: The template_uri of this ApiUsageRow.
        :type: str
        """
        
        self._template_uri = template_uri

    @property
    def http_method(self):
        """
        Gets the http_method of this ApiUsageRow.
        HTTP Method associated with this query result

        :return: The http_method of this ApiUsageRow.
        :rtype: str
        """
        return self._http_method

    @http_method.setter
    def http_method(self, http_method):
        """
        Sets the http_method of this ApiUsageRow.
        HTTP Method associated with this query result

        :param http_method: The http_method of this ApiUsageRow.
        :type: str
        """
        
        self._http_method = http_method

    @property
    def status200(self):
        """
        Gets the status200 of this ApiUsageRow.
        Number of requests resulting in a 2xx HTTP status code

        :return: The status200 of this ApiUsageRow.
        :rtype: int
        """
        return self._status200

    @status200.setter
    def status200(self, status200):
        """
        Sets the status200 of this ApiUsageRow.
        Number of requests resulting in a 2xx HTTP status code

        :param status200: The status200 of this ApiUsageRow.
        :type: int
        """
        
        self._status200 = status200

    @property
    def status300(self):
        """
        Gets the status300 of this ApiUsageRow.
        Number of requests resulting in a 3xx HTTP status code

        :return: The status300 of this ApiUsageRow.
        :rtype: int
        """
        return self._status300

    @status300.setter
    def status300(self, status300):
        """
        Sets the status300 of this ApiUsageRow.
        Number of requests resulting in a 3xx HTTP status code

        :param status300: The status300 of this ApiUsageRow.
        :type: int
        """
        
        self._status300 = status300

    @property
    def status400(self):
        """
        Gets the status400 of this ApiUsageRow.
        Number of requests resulting in a 4xx HTTP status code

        :return: The status400 of this ApiUsageRow.
        :rtype: int
        """
        return self._status400

    @status400.setter
    def status400(self, status400):
        """
        Sets the status400 of this ApiUsageRow.
        Number of requests resulting in a 4xx HTTP status code

        :param status400: The status400 of this ApiUsageRow.
        :type: int
        """
        
        self._status400 = status400

    @property
    def status500(self):
        """
        Gets the status500 of this ApiUsageRow.
        Number of requests resulting in a 5xx HTTP status code

        :return: The status500 of this ApiUsageRow.
        :rtype: int
        """
        return self._status500

    @status500.setter
    def status500(self, status500):
        """
        Sets the status500 of this ApiUsageRow.
        Number of requests resulting in a 5xx HTTP status code

        :param status500: The status500 of this ApiUsageRow.
        :type: int
        """
        
        self._status500 = status500

    @property
    def status429(self):
        """
        Gets the status429 of this ApiUsageRow.
        Number of requests resulting in a 429 HTTP status code, this is a subset of the count returned with status400

        :return: The status429 of this ApiUsageRow.
        :rtype: int
        """
        return self._status429

    @status429.setter
    def status429(self, status429):
        """
        Sets the status429 of this ApiUsageRow.
        Number of requests resulting in a 429 HTTP status code, this is a subset of the count returned with status400

        :param status429: The status429 of this ApiUsageRow.
        :type: int
        """
        
        self._status429 = status429

    @property
    def requests(self):
        """
        Gets the requests of this ApiUsageRow.
        Total number of requests

        :return: The requests of this ApiUsageRow.
        :rtype: int
        """
        return self._requests

    @requests.setter
    def requests(self, requests):
        """
        Sets the requests of this ApiUsageRow.
        Total number of requests

        :param requests: The requests of this ApiUsageRow.
        :type: int
        """
        
        self._requests = requests

    @property
    def date(self):
        """
        Gets the date of this ApiUsageRow.
        Date of requests, based on granularity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date of this ApiUsageRow.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this ApiUsageRow.
        Date of requests, based on granularity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date: The date of this ApiUsageRow.
        :type: datetime
        """
        
        self._date = date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationSocialExpressionEventTopicMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationSocialExpressionEventTopicMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'held': 'bool',
            'error_info': 'QueueConversationSocialExpressionEventTopicErrorDetails',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'to_address': 'QueueConversationSocialExpressionEventTopicAddress',
            'from_address': 'QueueConversationSocialExpressionEventTopicAddress',
            'messages': 'list[QueueConversationSocialExpressionEventTopicMessageDetails]',
            'messages_transcript_uri': 'str',
            'type': 'str',
            'recipient_country': 'str',
            'recipient_type': 'str',
            'journey_context': 'QueueConversationSocialExpressionEventTopicJourneyContext',
            'wrapup': 'QueueConversationSocialExpressionEventTopicWrapup',
            'after_call_work': 'QueueConversationSocialExpressionEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'held': 'held',
            'error_info': 'errorInfo',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'to_address': 'toAddress',
            'from_address': 'fromAddress',
            'messages': 'messages',
            'messages_transcript_uri': 'messagesTranscriptUri',
            'type': 'type',
            'recipient_country': 'recipientCountry',
            'recipient_type': 'recipientType',
            'journey_context': 'journeyContext',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._held = None
        self._error_info = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._to_address = None
        self._from_address = None
        self._messages = None
        self._messages_transcript_uri = None
        self._type = None
        self._recipient_country = None
        self._recipient_type = None
        self._journey_context = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The id of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationSocialExpressionEventTopicMessage.


        :param id: The id of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The state of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationSocialExpressionEventTopicMessage.


        :param state: The state of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        allowed_values = ["ALERTING", "CONNECTED", "DISCONNECTED"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def held(self):
        """
        Gets the held of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The held of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationSocialExpressionEventTopicMessage.


        :param held: The held of this QueueConversationSocialExpressionEventTopicMessage.
        :type: bool
        """
        
        self._held = held

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The error_info of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: QueueConversationSocialExpressionEventTopicErrorDetails
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationSocialExpressionEventTopicMessage.


        :param error_info: The error_info of this QueueConversationSocialExpressionEventTopicMessage.
        :type: QueueConversationSocialExpressionEventTopicErrorDetails
        """
        
        self._error_info = error_info

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The provider of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationSocialExpressionEventTopicMessage.


        :param provider: The provider of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The script_id of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationSocialExpressionEventTopicMessage.


        :param script_id: The script_id of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The peer_id of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationSocialExpressionEventTopicMessage.


        :param peer_id: The peer_id of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The disconnect_type of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationSocialExpressionEventTopicMessage.


        :param disconnect_type: The disconnect_type of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The start_hold_time of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationSocialExpressionEventTopicMessage.


        :param start_hold_time: The start_hold_time of this QueueConversationSocialExpressionEventTopicMessage.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The connected_time of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationSocialExpressionEventTopicMessage.


        :param connected_time: The connected_time of this QueueConversationSocialExpressionEventTopicMessage.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The disconnected_time of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationSocialExpressionEventTopicMessage.


        :param disconnected_time: The disconnected_time of this QueueConversationSocialExpressionEventTopicMessage.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def to_address(self):
        """
        Gets the to_address of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The to_address of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: QueueConversationSocialExpressionEventTopicAddress
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this QueueConversationSocialExpressionEventTopicMessage.


        :param to_address: The to_address of this QueueConversationSocialExpressionEventTopicMessage.
        :type: QueueConversationSocialExpressionEventTopicAddress
        """
        
        self._to_address = to_address

    @property
    def from_address(self):
        """
        Gets the from_address of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The from_address of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: QueueConversationSocialExpressionEventTopicAddress
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this QueueConversationSocialExpressionEventTopicMessage.


        :param from_address: The from_address of this QueueConversationSocialExpressionEventTopicMessage.
        :type: QueueConversationSocialExpressionEventTopicAddress
        """
        
        self._from_address = from_address

    @property
    def messages(self):
        """
        Gets the messages of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The messages of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: list[QueueConversationSocialExpressionEventTopicMessageDetails]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this QueueConversationSocialExpressionEventTopicMessage.


        :param messages: The messages of this QueueConversationSocialExpressionEventTopicMessage.
        :type: list[QueueConversationSocialExpressionEventTopicMessageDetails]
        """
        
        self._messages = messages

    @property
    def messages_transcript_uri(self):
        """
        Gets the messages_transcript_uri of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The messages_transcript_uri of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._messages_transcript_uri

    @messages_transcript_uri.setter
    def messages_transcript_uri(self, messages_transcript_uri):
        """
        Sets the messages_transcript_uri of this QueueConversationSocialExpressionEventTopicMessage.


        :param messages_transcript_uri: The messages_transcript_uri of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._messages_transcript_uri = messages_transcript_uri

    @property
    def type(self):
        """
        Gets the type of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The type of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this QueueConversationSocialExpressionEventTopicMessage.


        :param type: The type of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        allowed_values = ["UNKNOWN", "SMS", "TWITTER", "FACEBOOK", "LINE", "VIBER", "WECHAT", "WHATSAPP", "TELEGRAM", "KAKAO", "WEBMESSAGING"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def recipient_country(self):
        """
        Gets the recipient_country of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The recipient_country of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """
        Sets the recipient_country of this QueueConversationSocialExpressionEventTopicMessage.


        :param recipient_country: The recipient_country of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._recipient_country = recipient_country

    @property
    def recipient_type(self):
        """
        Gets the recipient_type of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The recipient_type of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: str
        """
        return self._recipient_type

    @recipient_type.setter
    def recipient_type(self, recipient_type):
        """
        Sets the recipient_type of this QueueConversationSocialExpressionEventTopicMessage.


        :param recipient_type: The recipient_type of this QueueConversationSocialExpressionEventTopicMessage.
        :type: str
        """
        
        self._recipient_type = recipient_type

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The journey_context of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: QueueConversationSocialExpressionEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationSocialExpressionEventTopicMessage.


        :param journey_context: The journey_context of this QueueConversationSocialExpressionEventTopicMessage.
        :type: QueueConversationSocialExpressionEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The wrapup of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: QueueConversationSocialExpressionEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationSocialExpressionEventTopicMessage.


        :param wrapup: The wrapup of this QueueConversationSocialExpressionEventTopicMessage.
        :type: QueueConversationSocialExpressionEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The after_call_work of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: QueueConversationSocialExpressionEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationSocialExpressionEventTopicMessage.


        :param after_call_work: The after_call_work of this QueueConversationSocialExpressionEventTopicMessage.
        :type: QueueConversationSocialExpressionEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The after_call_work_required of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationSocialExpressionEventTopicMessage.


        :param after_call_work_required: The after_call_work_required of this QueueConversationSocialExpressionEventTopicMessage.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationSocialExpressionEventTopicMessage.


        :return: The additional_properties of this QueueConversationSocialExpressionEventTopicMessage.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationSocialExpressionEventTopicMessage.


        :param additional_properties: The additional_properties of this QueueConversationSocialExpressionEventTopicMessage.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'request_id': 'str',
            'date_import_started': 'WfmHistoricalDataUploadRequestStatusTopicDateTime',
            'date_import_ended': 'WfmHistoricalDataUploadRequestStatusTopicDateTime',
            'date_created': 'WfmHistoricalDataUploadRequestStatusTopicDateTime',
            'date_modified': 'WfmHistoricalDataUploadRequestStatusTopicDateTime',
            'status': 'str',
            'error': 'str',
            'active': 'bool'
        }

        self.attribute_map = {
            'request_id': 'requestId',
            'date_import_started': 'dateImportStarted',
            'date_import_ended': 'dateImportEnded',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'status': 'status',
            'error': 'error',
            'active': 'active'
        }

        self._request_id = None
        self._date_import_started = None
        self._date_import_ended = None
        self._date_created = None
        self._date_modified = None
        self._status = None
        self._error = None
        self._active = None

    @property
    def request_id(self):
        """
        Gets the request_id of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The request_id of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param request_id: The request_id of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: str
        """
        
        self._request_id = request_id

    @property
    def date_import_started(self):
        """
        Gets the date_import_started of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The date_import_started of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        return self._date_import_started

    @date_import_started.setter
    def date_import_started(self, date_import_started):
        """
        Sets the date_import_started of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param date_import_started: The date_import_started of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        
        self._date_import_started = date_import_started

    @property
    def date_import_ended(self):
        """
        Gets the date_import_ended of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The date_import_ended of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        return self._date_import_ended

    @date_import_ended.setter
    def date_import_ended(self, date_import_ended):
        """
        Sets the date_import_ended of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param date_import_ended: The date_import_ended of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        
        self._date_import_ended = date_import_ended

    @property
    def date_created(self):
        """
        Gets the date_created of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The date_created of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param date_created: The date_created of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The date_modified of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param date_modified: The date_modified of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: WfmHistoricalDataUploadRequestStatusTopicDateTime
        """
        
        self._date_modified = date_modified

    @property
    def status(self):
        """
        Gets the status of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The status of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param status: The status of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: str
        """
        allowed_values = ["Initiated", "InProgress", "Pending", "Success", "Failed", "Cancelled", "Purged", "PurgePending"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def error(self):
        """
        Gets the error of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The error of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """
        Sets the error of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param error: The error of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: str
        """
        
        self._error = error

    @property
    def active(self):
        """
        Gets the active of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :return: The active of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.


        :param active: The active of this WfmHistoricalDataUploadRequestStatusTopicHistoricalDataUploadRequestUpdate.
        :type: bool
        """
        
        self._active = active

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DomainPermission(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainPermission - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'domain': 'str',
            'entity_type': 'str',
            'action': 'str',
            'label': 'str',
            'allows_conditions': 'bool',
            'division_aware': 'bool'
        }

        self.attribute_map = {
            'domain': 'domain',
            'entity_type': 'entityType',
            'action': 'action',
            'label': 'label',
            'allows_conditions': 'allowsConditions',
            'division_aware': 'divisionAware'
        }

        self._domain = None
        self._entity_type = None
        self._action = None
        self._label = None
        self._allows_conditions = None
        self._division_aware = None

    @property
    def domain(self):
        """
        Gets the domain of this DomainPermission.


        :return: The domain of this DomainPermission.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this DomainPermission.


        :param domain: The domain of this DomainPermission.
        :type: str
        """
        
        self._domain = domain

    @property
    def entity_type(self):
        """
        Gets the entity_type of this DomainPermission.


        :return: The entity_type of this DomainPermission.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this DomainPermission.


        :param entity_type: The entity_type of this DomainPermission.
        :type: str
        """
        
        self._entity_type = entity_type

    @property
    def action(self):
        """
        Gets the action of this DomainPermission.


        :return: The action of this DomainPermission.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this DomainPermission.


        :param action: The action of this DomainPermission.
        :type: str
        """
        
        self._action = action

    @property
    def label(self):
        """
        Gets the label of this DomainPermission.


        :return: The label of this DomainPermission.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this DomainPermission.


        :param label: The label of this DomainPermission.
        :type: str
        """
        
        self._label = label

    @property
    def allows_conditions(self):
        """
        Gets the allows_conditions of this DomainPermission.


        :return: The allows_conditions of this DomainPermission.
        :rtype: bool
        """
        return self._allows_conditions

    @allows_conditions.setter
    def allows_conditions(self, allows_conditions):
        """
        Sets the allows_conditions of this DomainPermission.


        :param allows_conditions: The allows_conditions of this DomainPermission.
        :type: bool
        """
        
        self._allows_conditions = allows_conditions

    @property
    def division_aware(self):
        """
        Gets the division_aware of this DomainPermission.


        :return: The division_aware of this DomainPermission.
        :rtype: bool
        """
        return self._division_aware

    @division_aware.setter
    def division_aware(self, division_aware):
        """
        Sets the division_aware of this DomainPermission.


        :param division_aware: The division_aware of this DomainPermission.
        :type: bool
        """
        
        self._division_aware = division_aware

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class KnowledgeSearchResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KnowledgeSearchResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'search_id': 'str',
            'total': 'int',
            'page_count': 'int',
            'page_size': 'int',
            'page_number': 'int',
            'results': 'list[KnowledgeSearchDocument]'
        }

        self.attribute_map = {
            'search_id': 'searchId',
            'total': 'total',
            'page_count': 'pageCount',
            'page_size': 'pageSize',
            'page_number': 'pageNumber',
            'results': 'results'
        }

        self._search_id = None
        self._total = None
        self._page_count = None
        self._page_size = None
        self._page_number = None
        self._results = None

    @property
    def search_id(self):
        """
        Gets the search_id of this KnowledgeSearchResponse.
        Search Id

        :return: The search_id of this KnowledgeSearchResponse.
        :rtype: str
        """
        return self._search_id

    @search_id.setter
    def search_id(self, search_id):
        """
        Sets the search_id of this KnowledgeSearchResponse.
        Search Id

        :param search_id: The search_id of this KnowledgeSearchResponse.
        :type: str
        """
        
        self._search_id = search_id

    @property
    def total(self):
        """
        Gets the total of this KnowledgeSearchResponse.
        Total number of records returned

        :return: The total of this KnowledgeSearchResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this KnowledgeSearchResponse.
        Total number of records returned

        :param total: The total of this KnowledgeSearchResponse.
        :type: int
        """
        
        self._total = total

    @property
    def page_count(self):
        """
        Gets the page_count of this KnowledgeSearchResponse.
        Number of pages returned in the result calculated according to the pageSize and the total

        :return: The page_count of this KnowledgeSearchResponse.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this KnowledgeSearchResponse.
        Number of pages returned in the result calculated according to the pageSize and the total

        :param page_count: The page_count of this KnowledgeSearchResponse.
        :type: int
        """
        
        self._page_count = page_count

    @property
    def page_size(self):
        """
        Gets the page_size of this KnowledgeSearchResponse.
        Number of records according to the page size

        :return: The page_size of this KnowledgeSearchResponse.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this KnowledgeSearchResponse.
        Number of records according to the page size

        :param page_size: The page_size of this KnowledgeSearchResponse.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_number(self):
        """
        Gets the page_number of this KnowledgeSearchResponse.
        Current page number for the returned records

        :return: The page_number of this KnowledgeSearchResponse.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this KnowledgeSearchResponse.
        Current page number for the returned records

        :param page_number: The page_number of this KnowledgeSearchResponse.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def results(self):
        """
        Gets the results of this KnowledgeSearchResponse.
        Results associated to the search response

        :return: The results of this KnowledgeSearchResponse.
        :rtype: list[KnowledgeSearchDocument]
        """
        return self._results

    @results.setter
    def results(self, results):
        """
        Sets the results of this KnowledgeSearchResponse.
        Results associated to the search response

        :param results: The results of this KnowledgeSearchResponse.
        :type: list[KnowledgeSearchDocument]
        """
        
        self._results = results

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserScheduleFullDayTimeOffMarker(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserScheduleFullDayTimeOffMarker - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'management_unit_date': 'str',
            'activity_code_id': 'str',
            'is_paid': 'bool',
            'length_in_minutes': 'int',
            'description': 'str',
            'delete': 'bool'
        }

        self.attribute_map = {
            'management_unit_date': 'managementUnitDate',
            'activity_code_id': 'activityCodeId',
            'is_paid': 'isPaid',
            'length_in_minutes': 'lengthInMinutes',
            'description': 'description',
            'delete': 'delete'
        }

        self._management_unit_date = None
        self._activity_code_id = None
        self._is_paid = None
        self._length_in_minutes = None
        self._description = None
        self._delete = None

    @property
    def management_unit_date(self):
        """
        Gets the management_unit_date of this UserScheduleFullDayTimeOffMarker.
        The date associated with the time off request that this marker corresponds to.  Date only, in ISO-8601 format.

        :return: The management_unit_date of this UserScheduleFullDayTimeOffMarker.
        :rtype: str
        """
        return self._management_unit_date

    @management_unit_date.setter
    def management_unit_date(self, management_unit_date):
        """
        Sets the management_unit_date of this UserScheduleFullDayTimeOffMarker.
        The date associated with the time off request that this marker corresponds to.  Date only, in ISO-8601 format.

        :param management_unit_date: The management_unit_date of this UserScheduleFullDayTimeOffMarker.
        :type: str
        """
        
        self._management_unit_date = management_unit_date

    @property
    def activity_code_id(self):
        """
        Gets the activity_code_id of this UserScheduleFullDayTimeOffMarker.
        The id for the activity code.  Look up a map of activity codes with the activities route

        :return: The activity_code_id of this UserScheduleFullDayTimeOffMarker.
        :rtype: str
        """
        return self._activity_code_id

    @activity_code_id.setter
    def activity_code_id(self, activity_code_id):
        """
        Sets the activity_code_id of this UserScheduleFullDayTimeOffMarker.
        The id for the activity code.  Look up a map of activity codes with the activities route

        :param activity_code_id: The activity_code_id of this UserScheduleFullDayTimeOffMarker.
        :type: str
        """
        
        self._activity_code_id = activity_code_id

    @property
    def is_paid(self):
        """
        Gets the is_paid of this UserScheduleFullDayTimeOffMarker.
        Whether this is paid time off

        :return: The is_paid of this UserScheduleFullDayTimeOffMarker.
        :rtype: bool
        """
        return self._is_paid

    @is_paid.setter
    def is_paid(self, is_paid):
        """
        Sets the is_paid of this UserScheduleFullDayTimeOffMarker.
        Whether this is paid time off

        :param is_paid: The is_paid of this UserScheduleFullDayTimeOffMarker.
        :type: bool
        """
        
        self._is_paid = is_paid

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this UserScheduleFullDayTimeOffMarker.
        The length in minutes of this time off marker

        :return: The length_in_minutes of this UserScheduleFullDayTimeOffMarker.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this UserScheduleFullDayTimeOffMarker.
        The length in minutes of this time off marker

        :param length_in_minutes: The length_in_minutes of this UserScheduleFullDayTimeOffMarker.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def description(self):
        """
        Gets the description of this UserScheduleFullDayTimeOffMarker.
        The description associated with the time off request that this marker corresponds to

        :return: The description of this UserScheduleFullDayTimeOffMarker.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UserScheduleFullDayTimeOffMarker.
        The description associated with the time off request that this marker corresponds to

        :param description: The description of this UserScheduleFullDayTimeOffMarker.
        :type: str
        """
        
        self._description = description

    @property
    def delete(self):
        """
        Gets the delete of this UserScheduleFullDayTimeOffMarker.
        If marked true for updating an existing full day time off marker, it will be deleted

        :return: The delete of this UserScheduleFullDayTimeOffMarker.
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """
        Sets the delete of this UserScheduleFullDayTimeOffMarker.
        If marked true for updating an existing full day time off marker, it will be deleted

        :param delete: The delete of this UserScheduleFullDayTimeOffMarker.
        :type: bool
        """
        
        self._delete = delete

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class JourneySegment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        JourneySegment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'is_active': 'bool',
            'display_name': 'str',
            'version': 'int',
            'description': 'str',
            'color': 'str',
            'scope': 'str',
            'should_display_to_agent': 'bool',
            'context': 'Context',
            'journey': 'Journey',
            'external_segment': 'ExternalSegment',
            'assignment_expiration_days': 'int',
            'self_uri': 'str',
            'created_date': 'datetime',
            'modified_date': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'is_active': 'isActive',
            'display_name': 'displayName',
            'version': 'version',
            'description': 'description',
            'color': 'color',
            'scope': 'scope',
            'should_display_to_agent': 'shouldDisplayToAgent',
            'context': 'context',
            'journey': 'journey',
            'external_segment': 'externalSegment',
            'assignment_expiration_days': 'assignmentExpirationDays',
            'self_uri': 'selfUri',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate'
        }

        self._id = None
        self._is_active = None
        self._display_name = None
        self._version = None
        self._description = None
        self._color = None
        self._scope = None
        self._should_display_to_agent = None
        self._context = None
        self._journey = None
        self._external_segment = None
        self._assignment_expiration_days = None
        self._self_uri = None
        self._created_date = None
        self._modified_date = None

    @property
    def id(self):
        """
        Gets the id of this JourneySegment.
        The globally unique identifier for the object.

        :return: The id of this JourneySegment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this JourneySegment.
        The globally unique identifier for the object.

        :param id: The id of this JourneySegment.
        :type: str
        """
        
        self._id = id

    @property
    def is_active(self):
        """
        Gets the is_active of this JourneySegment.
        Whether or not the segment is active.

        :return: The is_active of this JourneySegment.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this JourneySegment.
        Whether or not the segment is active.

        :param is_active: The is_active of this JourneySegment.
        :type: bool
        """
        
        self._is_active = is_active

    @property
    def display_name(self):
        """
        Gets the display_name of this JourneySegment.
        The display name of the segment.

        :return: The display_name of this JourneySegment.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this JourneySegment.
        The display name of the segment.

        :param display_name: The display_name of this JourneySegment.
        :type: str
        """
        
        self._display_name = display_name

    @property
    def version(self):
        """
        Gets the version of this JourneySegment.
        The version of the segment.

        :return: The version of this JourneySegment.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this JourneySegment.
        The version of the segment.

        :param version: The version of this JourneySegment.
        :type: int
        """
        
        self._version = version

    @property
    def description(self):
        """
        Gets the description of this JourneySegment.
        A description of the segment.

        :return: The description of this JourneySegment.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this JourneySegment.
        A description of the segment.

        :param description: The description of this JourneySegment.
        :type: str
        """
        
        self._description = description

    @property
    def color(self):
        """
        Gets the color of this JourneySegment.
        The hexadecimal color value of the segment.

        :return: The color of this JourneySegment.
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this JourneySegment.
        The hexadecimal color value of the segment.

        :param color: The color of this JourneySegment.
        :type: str
        """
        
        self._color = color

    @property
    def scope(self):
        """
        Gets the scope of this JourneySegment.
        The target entity that a segment applies to.

        :return: The scope of this JourneySegment.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this JourneySegment.
        The target entity that a segment applies to.

        :param scope: The scope of this JourneySegment.
        :type: str
        """
        allowed_values = ["Session", "Customer"]
        if scope.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for scope -> " + scope)
            self._scope = "outdated_sdk_version"
        else:
            self._scope = scope

    @property
    def should_display_to_agent(self):
        """
        Gets the should_display_to_agent of this JourneySegment.
        Whether or not the segment should be displayed to agent/supervisor users.

        :return: The should_display_to_agent of this JourneySegment.
        :rtype: bool
        """
        return self._should_display_to_agent

    @should_display_to_agent.setter
    def should_display_to_agent(self, should_display_to_agent):
        """
        Sets the should_display_to_agent of this JourneySegment.
        Whether or not the segment should be displayed to agent/supervisor users.

        :param should_display_to_agent: The should_display_to_agent of this JourneySegment.
        :type: bool
        """
        
        self._should_display_to_agent = should_display_to_agent

    @property
    def context(self):
        """
        Gets the context of this JourneySegment.
        The context of the segment.

        :return: The context of this JourneySegment.
        :rtype: Context
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this JourneySegment.
        The context of the segment.

        :param context: The context of this JourneySegment.
        :type: Context
        """
        
        self._context = context

    @property
    def journey(self):
        """
        Gets the journey of this JourneySegment.
        The pattern of rules defining the segment.

        :return: The journey of this JourneySegment.
        :rtype: Journey
        """
        return self._journey

    @journey.setter
    def journey(self, journey):
        """
        Sets the journey of this JourneySegment.
        The pattern of rules defining the segment.

        :param journey: The journey of this JourneySegment.
        :type: Journey
        """
        
        self._journey = journey

    @property
    def external_segment(self):
        """
        Gets the external_segment of this JourneySegment.
        Details of an entity corresponding to this segment in an external system.

        :return: The external_segment of this JourneySegment.
        :rtype: ExternalSegment
        """
        return self._external_segment

    @external_segment.setter
    def external_segment(self, external_segment):
        """
        Sets the external_segment of this JourneySegment.
        Details of an entity corresponding to this segment in an external system.

        :param external_segment: The external_segment of this JourneySegment.
        :type: ExternalSegment
        """
        
        self._external_segment = external_segment

    @property
    def assignment_expiration_days(self):
        """
        Gets the assignment_expiration_days of this JourneySegment.
        Time, in days, from when the segment is assigned until it is automatically unassigned.

        :return: The assignment_expiration_days of this JourneySegment.
        :rtype: int
        """
        return self._assignment_expiration_days

    @assignment_expiration_days.setter
    def assignment_expiration_days(self, assignment_expiration_days):
        """
        Sets the assignment_expiration_days of this JourneySegment.
        Time, in days, from when the segment is assigned until it is automatically unassigned.

        :param assignment_expiration_days: The assignment_expiration_days of this JourneySegment.
        :type: int
        """
        
        self._assignment_expiration_days = assignment_expiration_days

    @property
    def self_uri(self):
        """
        Gets the self_uri of this JourneySegment.
        The URI for this object

        :return: The self_uri of this JourneySegment.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this JourneySegment.
        The URI for this object

        :param self_uri: The self_uri of this JourneySegment.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def created_date(self):
        """
        Gets the created_date of this JourneySegment.
        Timestamp indicating when the segment was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The created_date of this JourneySegment.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this JourneySegment.
        Timestamp indicating when the segment was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param created_date: The created_date of this JourneySegment.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this JourneySegment.
        Timestamp indicating when the the segment was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The modified_date of this JourneySegment.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this JourneySegment.
        Timestamp indicating when the the segment was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param modified_date: The modified_date of this JourneySegment.
        :type: datetime
        """
        
        self._modified_date = modified_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ReschedulingOptionsRunResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ReschedulingOptionsRunResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'existing_schedule': 'BuScheduleReference',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'management_units': 'list[ReschedulingManagementUnitResponse]',
            'agent_count': 'int',
            'activity_code_ids': 'list[str]',
            'do_not_change_weekly_paid_time': 'bool',
            'do_not_change_daily_paid_time': 'bool',
            'do_not_change_shift_start_times': 'bool',
            'do_not_change_manually_edited_shifts': 'bool'
        }

        self.attribute_map = {
            'existing_schedule': 'existingSchedule',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'management_units': 'managementUnits',
            'agent_count': 'agentCount',
            'activity_code_ids': 'activityCodeIds',
            'do_not_change_weekly_paid_time': 'doNotChangeWeeklyPaidTime',
            'do_not_change_daily_paid_time': 'doNotChangeDailyPaidTime',
            'do_not_change_shift_start_times': 'doNotChangeShiftStartTimes',
            'do_not_change_manually_edited_shifts': 'doNotChangeManuallyEditedShifts'
        }

        self._existing_schedule = None
        self._start_date = None
        self._end_date = None
        self._management_units = None
        self._agent_count = None
        self._activity_code_ids = None
        self._do_not_change_weekly_paid_time = None
        self._do_not_change_daily_paid_time = None
        self._do_not_change_shift_start_times = None
        self._do_not_change_manually_edited_shifts = None

    @property
    def existing_schedule(self):
        """
        Gets the existing_schedule of this ReschedulingOptionsRunResponse.
        The existing schedule to which this reschedule run applies

        :return: The existing_schedule of this ReschedulingOptionsRunResponse.
        :rtype: BuScheduleReference
        """
        return self._existing_schedule

    @existing_schedule.setter
    def existing_schedule(self, existing_schedule):
        """
        Sets the existing_schedule of this ReschedulingOptionsRunResponse.
        The existing schedule to which this reschedule run applies

        :param existing_schedule: The existing_schedule of this ReschedulingOptionsRunResponse.
        :type: BuScheduleReference
        """
        
        self._existing_schedule = existing_schedule

    @property
    def start_date(self):
        """
        Gets the start_date of this ReschedulingOptionsRunResponse.
        The start date of the period to reschedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this ReschedulingOptionsRunResponse.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this ReschedulingOptionsRunResponse.
        The start date of the period to reschedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this ReschedulingOptionsRunResponse.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this ReschedulingOptionsRunResponse.
        The end date of the period to reschedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_date of this ReschedulingOptionsRunResponse.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this ReschedulingOptionsRunResponse.
        The end date of the period to reschedule. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_date: The end_date of this ReschedulingOptionsRunResponse.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def management_units(self):
        """
        Gets the management_units of this ReschedulingOptionsRunResponse.
        Per-management unit rescheduling options

        :return: The management_units of this ReschedulingOptionsRunResponse.
        :rtype: list[ReschedulingManagementUnitResponse]
        """
        return self._management_units

    @management_units.setter
    def management_units(self, management_units):
        """
        Sets the management_units of this ReschedulingOptionsRunResponse.
        Per-management unit rescheduling options

        :param management_units: The management_units of this ReschedulingOptionsRunResponse.
        :type: list[ReschedulingManagementUnitResponse]
        """
        
        self._management_units = management_units

    @property
    def agent_count(self):
        """
        Gets the agent_count of this ReschedulingOptionsRunResponse.
        The number of agents to be considered in the reschedule

        :return: The agent_count of this ReschedulingOptionsRunResponse.
        :rtype: int
        """
        return self._agent_count

    @agent_count.setter
    def agent_count(self, agent_count):
        """
        Sets the agent_count of this ReschedulingOptionsRunResponse.
        The number of agents to be considered in the reschedule

        :param agent_count: The agent_count of this ReschedulingOptionsRunResponse.
        :type: int
        """
        
        self._agent_count = agent_count

    @property
    def activity_code_ids(self):
        """
        Gets the activity_code_ids of this ReschedulingOptionsRunResponse.
        The IDs of the activity codes being considered for reschedule

        :return: The activity_code_ids of this ReschedulingOptionsRunResponse.
        :rtype: list[str]
        """
        return self._activity_code_ids

    @activity_code_ids.setter
    def activity_code_ids(self, activity_code_ids):
        """
        Sets the activity_code_ids of this ReschedulingOptionsRunResponse.
        The IDs of the activity codes being considered for reschedule

        :param activity_code_ids: The activity_code_ids of this ReschedulingOptionsRunResponse.
        :type: list[str]
        """
        
        self._activity_code_ids = activity_code_ids

    @property
    def do_not_change_weekly_paid_time(self):
        """
        Gets the do_not_change_weekly_paid_time of this ReschedulingOptionsRunResponse.
        Whether weekly paid time is allowed to be changed

        :return: The do_not_change_weekly_paid_time of this ReschedulingOptionsRunResponse.
        :rtype: bool
        """
        return self._do_not_change_weekly_paid_time

    @do_not_change_weekly_paid_time.setter
    def do_not_change_weekly_paid_time(self, do_not_change_weekly_paid_time):
        """
        Sets the do_not_change_weekly_paid_time of this ReschedulingOptionsRunResponse.
        Whether weekly paid time is allowed to be changed

        :param do_not_change_weekly_paid_time: The do_not_change_weekly_paid_time of this ReschedulingOptionsRunResponse.
        :type: bool
        """
        
        self._do_not_change_weekly_paid_time = do_not_change_weekly_paid_time

    @property
    def do_not_change_daily_paid_time(self):
        """
        Gets the do_not_change_daily_paid_time of this ReschedulingOptionsRunResponse.
        Whether daily paid time is allowed to be changed

        :return: The do_not_change_daily_paid_time of this ReschedulingOptionsRunResponse.
        :rtype: bool
        """
        return self._do_not_change_daily_paid_time

    @do_not_change_daily_paid_time.setter
    def do_not_change_daily_paid_time(self, do_not_change_daily_paid_time):
        """
        Sets the do_not_change_daily_paid_time of this ReschedulingOptionsRunResponse.
        Whether daily paid time is allowed to be changed

        :param do_not_change_daily_paid_time: The do_not_change_daily_paid_time of this ReschedulingOptionsRunResponse.
        :type: bool
        """
        
        self._do_not_change_daily_paid_time = do_not_change_daily_paid_time

    @property
    def do_not_change_shift_start_times(self):
        """
        Gets the do_not_change_shift_start_times of this ReschedulingOptionsRunResponse.
        Whether shift start times are allowed to be changed

        :return: The do_not_change_shift_start_times of this ReschedulingOptionsRunResponse.
        :rtype: bool
        """
        return self._do_not_change_shift_start_times

    @do_not_change_shift_start_times.setter
    def do_not_change_shift_start_times(self, do_not_change_shift_start_times):
        """
        Sets the do_not_change_shift_start_times of this ReschedulingOptionsRunResponse.
        Whether shift start times are allowed to be changed

        :param do_not_change_shift_start_times: The do_not_change_shift_start_times of this ReschedulingOptionsRunResponse.
        :type: bool
        """
        
        self._do_not_change_shift_start_times = do_not_change_shift_start_times

    @property
    def do_not_change_manually_edited_shifts(self):
        """
        Gets the do_not_change_manually_edited_shifts of this ReschedulingOptionsRunResponse.
        Whether manually edited shifts are allowed to be changed

        :return: The do_not_change_manually_edited_shifts of this ReschedulingOptionsRunResponse.
        :rtype: bool
        """
        return self._do_not_change_manually_edited_shifts

    @do_not_change_manually_edited_shifts.setter
    def do_not_change_manually_edited_shifts(self, do_not_change_manually_edited_shifts):
        """
        Sets the do_not_change_manually_edited_shifts of this ReschedulingOptionsRunResponse.
        Whether manually edited shifts are allowed to be changed

        :param do_not_change_manually_edited_shifts: The do_not_change_manually_edited_shifts of this ReschedulingOptionsRunResponse.
        :type: bool
        """
        
        self._do_not_change_manually_edited_shifts = do_not_change_manually_edited_shifts

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class GDPRRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        GDPRRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'created_by': 'DomainEntityRef',
            'replacement_terms': 'list[ReplacementTerm]',
            'request_type': 'str',
            'created_date': 'datetime',
            'status': 'str',
            'subject': 'GDPRSubject',
            'results_url': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'created_by': 'createdBy',
            'replacement_terms': 'replacementTerms',
            'request_type': 'requestType',
            'created_date': 'createdDate',
            'status': 'status',
            'subject': 'subject',
            'results_url': 'resultsUrl',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._created_by = None
        self._replacement_terms = None
        self._request_type = None
        self._created_date = None
        self._status = None
        self._subject = None
        self._results_url = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this GDPRRequest.
        The globally unique identifier for the object.

        :return: The id of this GDPRRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this GDPRRequest.
        The globally unique identifier for the object.

        :param id: The id of this GDPRRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this GDPRRequest.


        :return: The name of this GDPRRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this GDPRRequest.


        :param name: The name of this GDPRRequest.
        :type: str
        """
        
        self._name = name

    @property
    def created_by(self):
        """
        Gets the created_by of this GDPRRequest.
        The user that created this request

        :return: The created_by of this GDPRRequest.
        :rtype: DomainEntityRef
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this GDPRRequest.
        The user that created this request

        :param created_by: The created_by of this GDPRRequest.
        :type: DomainEntityRef
        """
        
        self._created_by = created_by

    @property
    def replacement_terms(self):
        """
        Gets the replacement_terms of this GDPRRequest.
        The replacement terms for the provided search terms, in the case of a GDPR_UPDATE request

        :return: The replacement_terms of this GDPRRequest.
        :rtype: list[ReplacementTerm]
        """
        return self._replacement_terms

    @replacement_terms.setter
    def replacement_terms(self, replacement_terms):
        """
        Sets the replacement_terms of this GDPRRequest.
        The replacement terms for the provided search terms, in the case of a GDPR_UPDATE request

        :param replacement_terms: The replacement_terms of this GDPRRequest.
        :type: list[ReplacementTerm]
        """
        
        self._replacement_terms = replacement_terms

    @property
    def request_type(self):
        """
        Gets the request_type of this GDPRRequest.
        The type of GDPR request

        :return: The request_type of this GDPRRequest.
        :rtype: str
        """
        return self._request_type

    @request_type.setter
    def request_type(self, request_type):
        """
        Sets the request_type of this GDPRRequest.
        The type of GDPR request

        :param request_type: The request_type of this GDPRRequest.
        :type: str
        """
        allowed_values = ["GDPR_EXPORT", "GDPR_UPDATE", "GDPR_DELETE"]
        if request_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for request_type -> " + request_type)
            self._request_type = "outdated_sdk_version"
        else:
            self._request_type = request_type

    @property
    def created_date(self):
        """
        Gets the created_date of this GDPRRequest.
        When the request was submitted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The created_date of this GDPRRequest.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this GDPRRequest.
        When the request was submitted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param created_date: The created_date of this GDPRRequest.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def status(self):
        """
        Gets the status of this GDPRRequest.
        The status of the request

        :return: The status of this GDPRRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this GDPRRequest.
        The status of the request

        :param status: The status of this GDPRRequest.
        :type: str
        """
        allowed_values = ["INITIATED", "SEARCHING", "UPDATING", "DELETING", "COMPLETED", "ERROR", "FINALIZING"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def subject(self):
        """
        Gets the subject of this GDPRRequest.
        The subject of the GDPR request

        :return: The subject of this GDPRRequest.
        :rtype: GDPRSubject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this GDPRRequest.
        The subject of the GDPR request

        :param subject: The subject of this GDPRRequest.
        :type: GDPRSubject
        """
        
        self._subject = subject

    @property
    def results_url(self):
        """
        Gets the results_url of this GDPRRequest.
        The location where the results of the request can be retrieved

        :return: The results_url of this GDPRRequest.
        :rtype: str
        """
        return self._results_url

    @results_url.setter
    def results_url(self, results_url):
        """
        Sets the results_url of this GDPRRequest.
        The location where the results of the request can be retrieved

        :param results_url: The results_url of this GDPRRequest.
        :type: str
        """
        
        self._results_url = results_url

    @property
    def self_uri(self):
        """
        Gets the self_uri of this GDPRRequest.
        The URI for this object

        :return: The self_uri of this GDPRRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this GDPRRequest.
        The URI for this object

        :param self_uri: The self_uri of this GDPRRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HistoricalAdherenceQueryResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HistoricalAdherenceQueryResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user_id': 'str',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'adherence_percentage': 'float',
            'conformance_percentage': 'float',
            'impact': 'str',
            'exception_info': 'list[HistoricalAdherenceExceptionInfo]',
            'day_metrics': 'list[HistoricalAdherenceDayMetrics]',
            'actuals': 'list[HistoricalAdherenceActuals]'
        }

        self.attribute_map = {
            'user_id': 'userId',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'adherence_percentage': 'adherencePercentage',
            'conformance_percentage': 'conformancePercentage',
            'impact': 'impact',
            'exception_info': 'exceptionInfo',
            'day_metrics': 'dayMetrics',
            'actuals': 'actuals'
        }

        self._user_id = None
        self._start_date = None
        self._end_date = None
        self._adherence_percentage = None
        self._conformance_percentage = None
        self._impact = None
        self._exception_info = None
        self._day_metrics = None
        self._actuals = None

    @property
    def user_id(self):
        """
        Gets the user_id of this HistoricalAdherenceQueryResult.
        The ID of the user for whom the adherence is queried

        :return: The user_id of this HistoricalAdherenceQueryResult.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this HistoricalAdherenceQueryResult.
        The ID of the user for whom the adherence is queried

        :param user_id: The user_id of this HistoricalAdherenceQueryResult.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def start_date(self):
        """
        Gets the start_date of this HistoricalAdherenceQueryResult.
        Beginning of the date range that was queried, in ISO-8601 format

        :return: The start_date of this HistoricalAdherenceQueryResult.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this HistoricalAdherenceQueryResult.
        Beginning of the date range that was queried, in ISO-8601 format

        :param start_date: The start_date of this HistoricalAdherenceQueryResult.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this HistoricalAdherenceQueryResult.
        End of the date range that was queried, in ISO-8601 format. If it was not set, end date will be set to the queried time

        :return: The end_date of this HistoricalAdherenceQueryResult.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this HistoricalAdherenceQueryResult.
        End of the date range that was queried, in ISO-8601 format. If it was not set, end date will be set to the queried time

        :param end_date: The end_date of this HistoricalAdherenceQueryResult.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def adherence_percentage(self):
        """
        Gets the adherence_percentage of this HistoricalAdherenceQueryResult.
        Adherence percentage for this user, in the scale of 0 - 100

        :return: The adherence_percentage of this HistoricalAdherenceQueryResult.
        :rtype: float
        """
        return self._adherence_percentage

    @adherence_percentage.setter
    def adherence_percentage(self, adherence_percentage):
        """
        Sets the adherence_percentage of this HistoricalAdherenceQueryResult.
        Adherence percentage for this user, in the scale of 0 - 100

        :param adherence_percentage: The adherence_percentage of this HistoricalAdherenceQueryResult.
        :type: float
        """
        
        self._adherence_percentage = adherence_percentage

    @property
    def conformance_percentage(self):
        """
        Gets the conformance_percentage of this HistoricalAdherenceQueryResult.
        Conformance percentage for this user, in the scale of 0 - 100. Conformance percentage can be greater than 100 when the actual on queue time is greater than the scheduled on queue time for the same period.

        :return: The conformance_percentage of this HistoricalAdherenceQueryResult.
        :rtype: float
        """
        return self._conformance_percentage

    @conformance_percentage.setter
    def conformance_percentage(self, conformance_percentage):
        """
        Sets the conformance_percentage of this HistoricalAdherenceQueryResult.
        Conformance percentage for this user, in the scale of 0 - 100. Conformance percentage can be greater than 100 when the actual on queue time is greater than the scheduled on queue time for the same period.

        :param conformance_percentage: The conformance_percentage of this HistoricalAdherenceQueryResult.
        :type: float
        """
        
        self._conformance_percentage = conformance_percentage

    @property
    def impact(self):
        """
        Gets the impact of this HistoricalAdherenceQueryResult.
        The impact of the current adherence state for this user

        :return: The impact of this HistoricalAdherenceQueryResult.
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """
        Sets the impact of this HistoricalAdherenceQueryResult.
        The impact of the current adherence state for this user

        :param impact: The impact of this HistoricalAdherenceQueryResult.
        :type: str
        """
        allowed_values = ["Positive", "Negative", "Neutral", "Unknown"]
        if impact.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for impact -> " + impact)
            self._impact = "outdated_sdk_version"
        else:
            self._impact = impact

    @property
    def exception_info(self):
        """
        Gets the exception_info of this HistoricalAdherenceQueryResult.
        List of adherence exceptions for this user

        :return: The exception_info of this HistoricalAdherenceQueryResult.
        :rtype: list[HistoricalAdherenceExceptionInfo]
        """
        return self._exception_info

    @exception_info.setter
    def exception_info(self, exception_info):
        """
        Sets the exception_info of this HistoricalAdherenceQueryResult.
        List of adherence exceptions for this user

        :param exception_info: The exception_info of this HistoricalAdherenceQueryResult.
        :type: list[HistoricalAdherenceExceptionInfo]
        """
        
        self._exception_info = exception_info

    @property
    def day_metrics(self):
        """
        Gets the day_metrics of this HistoricalAdherenceQueryResult.
        Adherence and conformance metrics for days in query range

        :return: The day_metrics of this HistoricalAdherenceQueryResult.
        :rtype: list[HistoricalAdherenceDayMetrics]
        """
        return self._day_metrics

    @day_metrics.setter
    def day_metrics(self, day_metrics):
        """
        Sets the day_metrics of this HistoricalAdherenceQueryResult.
        Adherence and conformance metrics for days in query range

        :param day_metrics: The day_metrics of this HistoricalAdherenceQueryResult.
        :type: list[HistoricalAdherenceDayMetrics]
        """
        
        self._day_metrics = day_metrics

    @property
    def actuals(self):
        """
        Gets the actuals of this HistoricalAdherenceQueryResult.
        List of actual activity with offset for this user

        :return: The actuals of this HistoricalAdherenceQueryResult.
        :rtype: list[HistoricalAdherenceActuals]
        """
        return self._actuals

    @actuals.setter
    def actuals(self, actuals):
        """
        Sets the actuals of this HistoricalAdherenceQueryResult.
        List of actual activity with offset for this user

        :param actuals: The actuals of this HistoricalAdherenceQueryResult.
        :type: list[HistoricalAdherenceActuals]
        """
        
        self._actuals = actuals

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TimeOffRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TimeOffRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'user': 'UserReference',
            'is_full_day_request': 'bool',
            'marked_as_read': 'bool',
            'activity_code_id': 'str',
            'status': 'str',
            'partial_day_start_date_times': 'list[datetime]',
            'full_day_management_unit_dates': 'list[str]',
            'daily_duration_minutes': 'int',
            'notes': 'str',
            'submitted_by': 'UserReference',
            'submitted_date': 'datetime',
            'reviewed_by': 'UserReference',
            'reviewed_date': 'datetime',
            'metadata': 'WfmVersionedEntityMetadata',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'user': 'user',
            'is_full_day_request': 'isFullDayRequest',
            'marked_as_read': 'markedAsRead',
            'activity_code_id': 'activityCodeId',
            'status': 'status',
            'partial_day_start_date_times': 'partialDayStartDateTimes',
            'full_day_management_unit_dates': 'fullDayManagementUnitDates',
            'daily_duration_minutes': 'dailyDurationMinutes',
            'notes': 'notes',
            'submitted_by': 'submittedBy',
            'submitted_date': 'submittedDate',
            'reviewed_by': 'reviewedBy',
            'reviewed_date': 'reviewedDate',
            'metadata': 'metadata',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._user = None
        self._is_full_day_request = None
        self._marked_as_read = None
        self._activity_code_id = None
        self._status = None
        self._partial_day_start_date_times = None
        self._full_day_management_unit_dates = None
        self._daily_duration_minutes = None
        self._notes = None
        self._submitted_by = None
        self._submitted_date = None
        self._reviewed_by = None
        self._reviewed_date = None
        self._metadata = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TimeOffRequest.
        The id of the time off request

        :return: The id of this TimeOffRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TimeOffRequest.
        The id of the time off request

        :param id: The id of this TimeOffRequest.
        :type: str
        """
        
        self._id = id

    @property
    def user(self):
        """
        Gets the user of this TimeOffRequest.
        The user that the time off request belongs to

        :return: The user of this TimeOffRequest.
        :rtype: UserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this TimeOffRequest.
        The user that the time off request belongs to

        :param user: The user of this TimeOffRequest.
        :type: UserReference
        """
        
        self._user = user

    @property
    def is_full_day_request(self):
        """
        Gets the is_full_day_request of this TimeOffRequest.
        Whether this is a full day request (false means partial day)

        :return: The is_full_day_request of this TimeOffRequest.
        :rtype: bool
        """
        return self._is_full_day_request

    @is_full_day_request.setter
    def is_full_day_request(self, is_full_day_request):
        """
        Sets the is_full_day_request of this TimeOffRequest.
        Whether this is a full day request (false means partial day)

        :param is_full_day_request: The is_full_day_request of this TimeOffRequest.
        :type: bool
        """
        
        self._is_full_day_request = is_full_day_request

    @property
    def marked_as_read(self):
        """
        Gets the marked_as_read of this TimeOffRequest.
        Whether this request has been marked as read by the agent

        :return: The marked_as_read of this TimeOffRequest.
        :rtype: bool
        """
        return self._marked_as_read

    @marked_as_read.setter
    def marked_as_read(self, marked_as_read):
        """
        Sets the marked_as_read of this TimeOffRequest.
        Whether this request has been marked as read by the agent

        :param marked_as_read: The marked_as_read of this TimeOffRequest.
        :type: bool
        """
        
        self._marked_as_read = marked_as_read

    @property
    def activity_code_id(self):
        """
        Gets the activity_code_id of this TimeOffRequest.
        The ID of the activity code associated with this time off request. Activity code must be of the TimeOff category

        :return: The activity_code_id of this TimeOffRequest.
        :rtype: str
        """
        return self._activity_code_id

    @activity_code_id.setter
    def activity_code_id(self, activity_code_id):
        """
        Sets the activity_code_id of this TimeOffRequest.
        The ID of the activity code associated with this time off request. Activity code must be of the TimeOff category

        :param activity_code_id: The activity_code_id of this TimeOffRequest.
        :type: str
        """
        
        self._activity_code_id = activity_code_id

    @property
    def status(self):
        """
        Gets the status of this TimeOffRequest.
        The status of this time off request

        :return: The status of this TimeOffRequest.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TimeOffRequest.
        The status of this time off request

        :param status: The status of this TimeOffRequest.
        :type: str
        """
        allowed_values = ["PENDING", "APPROVED", "DENIED", "CANCELED"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def partial_day_start_date_times(self):
        """
        Gets the partial_day_start_date_times of this TimeOffRequest.
        A set of start date-times in ISO-8601 format for partial day requests.  Will be not empty if isFullDayRequest == false

        :return: The partial_day_start_date_times of this TimeOffRequest.
        :rtype: list[datetime]
        """
        return self._partial_day_start_date_times

    @partial_day_start_date_times.setter
    def partial_day_start_date_times(self, partial_day_start_date_times):
        """
        Sets the partial_day_start_date_times of this TimeOffRequest.
        A set of start date-times in ISO-8601 format for partial day requests.  Will be not empty if isFullDayRequest == false

        :param partial_day_start_date_times: The partial_day_start_date_times of this TimeOffRequest.
        :type: list[datetime]
        """
        
        self._partial_day_start_date_times = partial_day_start_date_times

    @property
    def full_day_management_unit_dates(self):
        """
        Gets the full_day_management_unit_dates of this TimeOffRequest.
        A set of dates in yyyy-MM-dd format.  Should be interpreted in the management unit's configured time zone.  Will be not empty if isFullDayRequest == true

        :return: The full_day_management_unit_dates of this TimeOffRequest.
        :rtype: list[str]
        """
        return self._full_day_management_unit_dates

    @full_day_management_unit_dates.setter
    def full_day_management_unit_dates(self, full_day_management_unit_dates):
        """
        Sets the full_day_management_unit_dates of this TimeOffRequest.
        A set of dates in yyyy-MM-dd format.  Should be interpreted in the management unit's configured time zone.  Will be not empty if isFullDayRequest == true

        :param full_day_management_unit_dates: The full_day_management_unit_dates of this TimeOffRequest.
        :type: list[str]
        """
        
        self._full_day_management_unit_dates = full_day_management_unit_dates

    @property
    def daily_duration_minutes(self):
        """
        Gets the daily_duration_minutes of this TimeOffRequest.
        The daily duration of this time off request in minutes

        :return: The daily_duration_minutes of this TimeOffRequest.
        :rtype: int
        """
        return self._daily_duration_minutes

    @daily_duration_minutes.setter
    def daily_duration_minutes(self, daily_duration_minutes):
        """
        Sets the daily_duration_minutes of this TimeOffRequest.
        The daily duration of this time off request in minutes

        :param daily_duration_minutes: The daily_duration_minutes of this TimeOffRequest.
        :type: int
        """
        
        self._daily_duration_minutes = daily_duration_minutes

    @property
    def notes(self):
        """
        Gets the notes of this TimeOffRequest.
        Notes about the time off request

        :return: The notes of this TimeOffRequest.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this TimeOffRequest.
        Notes about the time off request

        :param notes: The notes of this TimeOffRequest.
        :type: str
        """
        
        self._notes = notes

    @property
    def submitted_by(self):
        """
        Gets the submitted_by of this TimeOffRequest.
        The user who submitted this time off request

        :return: The submitted_by of this TimeOffRequest.
        :rtype: UserReference
        """
        return self._submitted_by

    @submitted_by.setter
    def submitted_by(self, submitted_by):
        """
        Sets the submitted_by of this TimeOffRequest.
        The user who submitted this time off request

        :param submitted_by: The submitted_by of this TimeOffRequest.
        :type: UserReference
        """
        
        self._submitted_by = submitted_by

    @property
    def submitted_date(self):
        """
        Gets the submitted_date of this TimeOffRequest.
        The timestamp when this request was submitted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The submitted_date of this TimeOffRequest.
        :rtype: datetime
        """
        return self._submitted_date

    @submitted_date.setter
    def submitted_date(self, submitted_date):
        """
        Sets the submitted_date of this TimeOffRequest.
        The timestamp when this request was submitted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param submitted_date: The submitted_date of this TimeOffRequest.
        :type: datetime
        """
        
        self._submitted_date = submitted_date

    @property
    def reviewed_by(self):
        """
        Gets the reviewed_by of this TimeOffRequest.
        The user who reviewed this time off request

        :return: The reviewed_by of this TimeOffRequest.
        :rtype: UserReference
        """
        return self._reviewed_by

    @reviewed_by.setter
    def reviewed_by(self, reviewed_by):
        """
        Sets the reviewed_by of this TimeOffRequest.
        The user who reviewed this time off request

        :param reviewed_by: The reviewed_by of this TimeOffRequest.
        :type: UserReference
        """
        
        self._reviewed_by = reviewed_by

    @property
    def reviewed_date(self):
        """
        Gets the reviewed_date of this TimeOffRequest.
        The timestamp when this request was reviewed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The reviewed_date of this TimeOffRequest.
        :rtype: datetime
        """
        return self._reviewed_date

    @reviewed_date.setter
    def reviewed_date(self, reviewed_date):
        """
        Sets the reviewed_date of this TimeOffRequest.
        The timestamp when this request was reviewed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param reviewed_date: The reviewed_date of this TimeOffRequest.
        :type: datetime
        """
        
        self._reviewed_date = reviewed_date

    @property
    def metadata(self):
        """
        Gets the metadata of this TimeOffRequest.
        The version metadata of the time off request

        :return: The metadata of this TimeOffRequest.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TimeOffRequest.
        The version metadata of the time off request

        :param metadata: The metadata of this TimeOffRequest.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TimeOffRequest.
        The URI for this object

        :return: The self_uri of this TimeOffRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TimeOffRequest.
        The URI for this object

        :param self_uri: The self_uri of this TimeOffRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

